import com.huawei.sis.bean.AuthInfo;
import com.huawei.sis.bean.SisConfig;
import com.huawei.sis.bean.SisConstant;
import com.huawei.sis.bean.request.PaAudioRequest;
import com.huawei.sis.bean.request.PaVideoRequest;
import com.huawei.sis.bean.response.PaResponse;
import com.huawei.sis.client.PaClient;
import com.huawei.sis.exception.SisException;
import com.huawei.sis.util.IOUtils;
import com.huawei.sis.util.JsonUtils;


/**
 * 口语评测，包含语音评测和多模态评测
 *
 * Copyright 2021 Huawei Technologies Co.,Ltd.
 */
public class PaDemo {
  private String ak = "";
  private String sk = "";
  private String region = "";       // 区域，目前仅支持cn-north-4
  private String projectId = "";    // 项目id，在我的凭证查看。参考https://support.huaweicloud.com/api-sis/sis_03_0008.html

  // 语音评测参数
  private String audioPath = "";        // 语音路径，如D:/test.wav, sdk提供将文件转化为base64编码接口。
  private String audioRefText = "";     // 识别标准文本，会根据发音和文本对比，得出分数。

  // 多模态评测参数
  private String videoPath = "";        // 视频路径，如D:/test.mp4, sdk提供将文件转化为base64编码接口。
  private String videoRefText = "";     // 识别标准文本，会根据发音和文本对比，得出分数。



  /**
   * 定义config，所有参数可选，设置超时时间等。
   *
   * @return SisConfig
   */
  private SisConfig getConfig() {
    SisConfig config = new SisConfig();
    // 设置连接超时，默认10000ms
    config.setConnectionTimeout(SisConstant.DEFAULT_CONNECTION_TIMEOUT);
    // 设置读取超时，默认10000ms
    config.setReadTimeout(SisConstant.DEFAULT_READ_TIMEOUT);
    // 设置代理, 一定要确保代理可用才启动此设置。 代理初始化也可用不加密的代理，new ProxyHostInfo(host, port);
    // ProxyHostInfo proxy = new ProxyHostInfo(host, port, username, password);
    // config.setProxy(proxy);
    return config;
  }

  /**
   * 语音评测示例
   */
  private void assessmentAudioDemo() {
    try {
      // 1. 初始化client
      AuthInfo authInfo = new AuthInfo(ak, sk, region, projectId);
      SisConfig config = getConfig();
      PaClient paClient = new PaClient(authInfo, config);

      // 2. 配置请求
      String audioBase64 = IOUtils.getEncodeDataByPath(audioPath);
      PaAudioRequest paAudioRequest = new PaAudioRequest();
      // 设置音频base64编码
      paAudioRequest.setAudioData(audioBase64);
      // 设置音频标注文本
      paAudioRequest.setRefText(audioRefText);
      // 设置音频格式，具体支持格式请参考api文档。
      paAudioRequest.setAudioFormat("auto");
      // 设置语言，默认en_gb。具体支持详见api文档
      paAudioRequest.setLanguage("en_gb");
      // 设置模式，支持word和sentence模式。默认word。具体支持详见api文档。
      paAudioRequest.setMode("word");

      // 3. 发送请求，获取响应
      PaResponse paResponse = paClient.accessAudio(paAudioRequest);
      String jsonResult = JsonUtils.obj2Str(paResponse, true);
      // 具体信息可以通过PaResponse.getXX方法获取。
      System.out.println(jsonResult);

    } catch (SisException e) {
      e.printStackTrace();
      System.out.println("error_code:" + e.getErrorCode() + "\nerror_msg:" + e.getErrorMsg());
    }
  }

  /**
   * 多模态评测示例
   */
  private void assessmentVideoDemo() {
    try {
      // 1. 初始化client
      AuthInfo authInfo = new AuthInfo(ak, sk, region, projectId);
      SisConfig config = getConfig();
      PaClient paClient = new PaClient(authInfo, config);

      // 2. 配置请求
      String videoBase64 = IOUtils.getEncodeDataByPath(videoPath);
      PaVideoRequest paVideoRequest = new PaVideoRequest();
      // 设置视频base64编码
      paVideoRequest.setVideoData(videoBase64);
      // 设置音频标注文本
      paVideoRequest.setRefText(videoRefText);
      // 设置音频格式,具体支持格式请参考api文档。
      paVideoRequest.setVideoFormat("auto");
      // 设置语言，默认en_gb。具体支持详见api文档
      paVideoRequest.setLanguage("en_gb");
      // 设置模式，支持word和sentence模式。默认word。具体支持详见api文档。
      paVideoRequest.setMode("word");

      // 3. 发送请求，获取响应
      // 具体信息可以通过PaResponse.getXX方法获取。
      PaResponse paResponse = paClient.accessVideo(paVideoRequest);
      System.out.println(JsonUtils.obj2Str(paResponse, true));


    } catch (SisException e) {
      e.printStackTrace();
      System.out.println("error_code:" + e.getErrorCode() + "\nerror_msg:" + e.getErrorMsg());
    }
  }


  public static void main(String[] args) {
    PaDemo paDemo = new PaDemo();
    // 语音评测
    paDemo.assessmentAudioDemo();

    // 多模态评测
    paDemo.assessmentVideoDemo();
  }
}
